@@ -40,6 +40,9 @@
 
 #include "cbdata.h"
 
+/* for CacheDigestGuessStats */
+#include "StatCounters.h"
+
 struct _Version {
     short int current;		/* current version */
     short int required;		/* minimal version that can safely handle current version */
@@ -61,6 +64,10 @@ public:
     int reserved[32 - 6];
 };
 
+class HttpRequest;
+class PeerDigest;
+class store_client;
+
 struct _DigestFetchState {
     PeerDigest *pd;
     StoreEntry *entry;
@@ -116,7 +123,7 @@ public:
     } times;
 
     struct {
-        cd_guess_stats guess;
+        CacheDigestGuessStats guess;
         int used_count;
 
         struct {
