@@ -33,9 +33,11 @@
  *
  */
 
-#include "squid.h"
+#include "squid-old.h"
 #include "comm.h"
 #include "fde.h"
+#include "ip/Address.h"
+#include "rfc1738.h"
 #include "SquidTime.h"
 
 #ifndef _MSWSOCK_
@@ -301,7 +303,7 @@ ipcCreate(int type, const char *prog, const char *const args[], const char *name
 
     hello_buf[x] = '\0';
     pid = atol(hello_buf);
-    commSetTimeout(prfd, -1, NULL, NULL);
+    commUnsetFdTimeout(prfd);
     commSetNonBlocking(prfd);
     commSetNonBlocking(pwfd);
     commSetCloseOnExec(prfd);
@@ -545,7 +547,7 @@ ipc_thread_1(void *in_params)
     si.dwFlags = STARTF_USESTDHANDLES;
 
     /* Make sure all other valid handles are not inerithable */
-    for (x = 3; x < Squid_MaxFD; x++) {
+    for (x = 3; x < Squid_MaxFD; ++x) {
         if ((F = _get_osfhandle(x)) == -1)
             continue;
 
@@ -564,7 +566,8 @@ ipc_thread_1(void *in_params)
     x = 1;
 
     while (args[x]) {
-        strcat(buf1, args[x++]);
+        strcat(buf1, args[x]);
+        ++x;
         strcat(buf1, " ");
     }
 
@@ -574,8 +577,7 @@ ipc_thread_1(void *in_params)
         hProcess = pi.hProcess;
     } else {
         pid = -1;
-        WIN32_maperror(GetLastError());
-        x = errno;
+        x = GetLastError();
     }
 
     dup2(t1, 0);
@@ -831,7 +833,7 @@ ipc_thread_2(void *in_params)
             if ((buf2[x - 1] == '\n') && (buf2[x - 2] == '\r')) {
                 buf2[x - 2] = '\n';
                 buf2[x - 1] = '\0';
-                x--;
+                --x;
             }
         }
 
